#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 repline
version:              0.4.0.0
visibility:           public
id:                   repline-0.4.0.0-KFIMb37KT4JF8sbXX0sefZ
key:                  repline-0.4.0.0-KFIMb37KT4JF8sbXX0sefZ
license:              MIT
copyright:            2014-2020 Stephen Diehl
maintainer:           stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/repline
synopsis:             Haskeline wrapper for GHCi-like REPL interfaces.
description:
    Haskeline wrapper for GHCi-like REPL interfaces. Composable with normal mtl transformers.

category:             User Interfaces
abi:                  c83078c181ab59ec768985efaf871aaa
exposed:              True
exposed-modules:      System.Console.Repline
import-dirs:          /usr/lib/ghc-8.10.5/site-local/repline-0.4.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/repline-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/repline-0.4.0.0
hs-libraries:         HSrepline-0.4.0.0-KFIMb37KT4JF8sbXX0sefZ
depends:
    base-4.14.2.0 containers-0.6.4.1 exceptions-0.10.4
    haskeline-0.8.0.1 mtl-2.2.2 process-1.6.9.0

haddock-interfaces:   /usr/share/doc/haskell-repline/html/repline.haddock
haddock-html:         /usr/share/doc/haskell-repline/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

